closeHeadsUpNotification abstract method
Closes the currently visible heads up notification.
If no heads up notification is visible, the behavior is undefined.
Implementation
Future<void> closeHeadsUpNotification();
Closes the currently visible heads up notification.
If no heads up notification is visible, the behavior is undefined.
Future<void> closeHeadsUpNotification();