tapOnNotificationByIndex method
Searches for the index-th visible notification and taps on it.
Notification shade has to be opened first with openNotifications.
See also:
- tapOnNotificationBySelector, which allows for more precise specification of the notification to tap on
Implementation
Future<void> tapOnNotificationByIndex(int index, {Duration? timeout}) {
return platform.action.mobile(
android: () =>
platform.android.tapOnNotificationByIndex(index, timeout: timeout),
ios: () => platform.ios.tapOnNotificationByIndex(index, timeout: timeout),
);
}