waitUntilExists method

Future<PatrolFinder> waitUntilExists({
  1. Duration? timeout,
})

Waits until this finder finds at least one widget.

Throws a WaitUntilVisibleTimeoutException if no widgets found.

Timeout is globally set by PatrolTesterConfig.visibleTimeout inside PatrolTester.config. If you want to override this global setting, set timeout.

Implementation

Future<PatrolFinder> waitUntilExists({Duration? timeout}) =>
    wrapWithPatrolLog(
      action: 'waitUntilExists',
      color: AnsiCodes.cyan,
      function: () => tester.waitUntilExists(
        this,
        timeout: timeout,
        enablePatrolLog: false,
      ),
    );